==> cdk-datalake-constructs-0.0.39.tar.gz: package/lib/etl/glue-job.d.ts <==
import * as cloudwatch from '@aws-cdk/aws-cloudwatch';
import * as events from '@aws-cdk/aws-events';
import * as glue from '@aws-cdk/aws-glue';
import * as iam from '@aws-cdk/aws-iam';
import * as lambda from '@aws-cdk/aws-lambda';
import * as s3 from '@aws-cdk/aws-s3';
import * as cdk from '@aws-cdk/core';
/**
 * @experimental
 */
export declare enum GlueWorkerType {
    /**
     * @experimental
     */
    STANDARD = "Standard",
    /**
     * @experimental
     */
    G1_X = "G.1X",
    /**
     * @experimental
     */
    G2_X = "G.2X"
}
/**
 * @experimental
 */
export declare enum GlueVersion {
    /**
     * @experimental
     */
    V_0 = "0.9",
    /**
     * @experimental
     */
    V_1 = "1.0",
    /**
     * @experimental
     */
    V_2 = "2.0"
}
/**
 * @experimental
 */
export declare enum GlueJobType {
    /**
     * @experimental
     */
    GLUE_ETL = "glueetl",
    /**
     * @experimental
     */
    GLUE_STREAMING = "gluestreaming"
}
/**
 * @experimental
 */
export interface GlueJobProperties {
    /**
     * @experimental
     */
    readonly name: string;
    /**
     * @experimental
     */
    readonly roleName?: string;
    /**
     * @experimental
     */
    readonly description?: string;
    /**
     * @experimental
     */
    readonly deploymentBucket: s3.IBucket;
    /**
     * @experimental
     */
    readonly readAccessBuckets?: s3.IBucket[];
    /**
     * @experimental
     */
    readonly writeAccessBuckets?: s3.IBucket[];
    /**
     * @experimental
     */
    readonly glueVersion?: GlueVersion;
    /**
     * @experimental
     */
    readonly workerType: GlueWorkerType;
    /**
     * @experimental
     */
    readonly numberOfWorkers?: number;
    /**
     * @experimental
     */
    readonly maxCapacity?: number;
    /**
     * @experimental
     */
    readonly maxRetries?: number;
    /**
     * @experimental
     */
    readonly maxConcurrentRuns?: number;
    /**
     * @experimental
     */
    readonly jobScript: string;
    /**
     * @experimental
     */
    readonly jobArgs?: {
        [key: string]: string;
    };
    /**
     * @experimental
     */
    readonly timeout?: number;
    /**
     * @experimental
     */
    readonly jobType: GlueJobType;
}
/**
 * @experimental
 */
export declare class GlueJob extends cdk.Construct {
    private static readonly DAY_IN_MINUTES;
    /**
     * @experimental
     */
    readonly job: glue.CfnJob;
    /**
     * @experimental
     */
    readonly role: iam.IRole;
    /**
     * @experimental
     */
    readonly name: string;
    /**
     * @experimental
     */
    readonly metricSuccessRule: events.Rule;
    /**
     * @experimental
     */
    readonly metricTimeoutRule: events.Rule;
    /**
     * @experimental
     */
    readonly metricFailureRule: events.Rule;
    /**
     * @experimental
     */
    readonly allExecutionAttemptsFailedEventSource = "custom.aws.glue.allExecutionAttemptsFailed";
    /**
     * @experimental
     */
    readonly allExecutionAttemptsFailedEventDetailType = "All Execution Attempts Failed";
    /**
     * @experimental
     */
    readonly executionFailureRule: events.Rule;
    /**
     * @experimental
     */
    readonly lambdaFunction: lambda.SingletonFunction;
    private allExecutionAttemptsFailedRule;
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: GlueJobProperties);
    private createGlueJobRole;
    private jobRule;
    /**
     * @experimental
     */
    metricSuccess(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @experimental
     */
    metricFailure(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @experimental
     */
    metricAllExecutionAttemptsFailed(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @experimental
     */
    metricTimeout(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    private ruleMetric;
    /**
     * @experimental
     */
    metric(metricName: string, dimensionType: string, props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @experimental
     */
    jvmHeapUsageMetric(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @experimental
     */
    elapsedTimeMetric(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @experimental
     */
    diskSpaceUsedMbMetric(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @experimental
     */
    runTimeInMiliseconds(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    private createLambdaFunction;
}

==> cdk-datalake-constructs-0.0.44.tar.gz: package/lib/etl/glue-job.d.ts <==
import * as cloudwatch from 'aws-cdk-lib/aws-cloudwatch';
import * as events from 'aws-cdk-lib/aws-events';
import * as glue from 'aws-cdk-lib/aws-glue';
import * as iam from 'aws-cdk-lib/aws-iam';
import * as lambda from 'aws-cdk-lib/aws-lambda';
import * as s3 from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
/**
 * @stability stable
 */
export declare enum GlueWorkerType {
    /**
     * @stability stable
     */
    STANDARD = "Standard",
    /**
     * @stability stable
     */
    G1_X = "G.1X",
    /**
     * @stability stable
     */
    G2_X = "G.2X"
}
/**
 * @stability stable
 */
export declare enum GlueVersion {
    /**
     * @stability stable
     */
    V_0 = "0.9",
    /**
     * @stability stable
     */
    V_1 = "1.0",
    /**
     * @stability stable
     */
    V_2 = "2.0",
    /**
     * @stability stable
     */
    V_3 = "3.0"
}
/**
 * @stability stable
 */
export declare enum GlueJobType {
    /**
     * @stability stable
     */
    GLUE_ETL = "glueetl",
    /**
     * @stability stable
     */
    GLUE_STREAMING = "gluestreaming"
}
/**
 * @stability stable
 */
export interface GlueJobProperties {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly roleName?: string;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly deploymentBucket: s3.IBucket;
    /**
     * @stability stable
     */
    readonly readAccessBuckets?: s3.IBucket[];
    /**
     * @stability stable
     */
    readonly writeAccessBuckets?: s3.IBucket[];
    /**
     * @stability stable
     */
    readonly glueVersion?: GlueVersion;
    /**
     * @stability stable
     */
    readonly workerType: GlueWorkerType;
    /**
     * @stability stable
     */
    readonly numberOfWorkers?: number;
    /**
     * @stability stable
     */
    readonly maxCapacity?: number;
    /**
     * @stability stable
     */
    readonly maxRetries?: number;
    /**
     * @stability stable
     */
    readonly maxConcurrentRuns?: number;
    /**
     * @stability stable
     */
    readonly jobScript: string;
    /**
     * @stability stable
     */
    readonly jobArgs?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * @stability stable
     */
    readonly jobType: GlueJobType;
}
/**
 * @stability stable
 */
export declare class GlueJob extends Construct {
    private static readonly DAY_IN_MINUTES;
    /**
     * @stability stable
     */
    readonly job: glue.CfnJob;
    /**
     * @stability stable
     */
    readonly role: iam.IRole;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly metricSuccessRule: events.Rule;
    /**
     * @stability stable
     */
    readonly metricTimeoutRule: events.Rule;
    /**
     * @stability stable
     */
    readonly metricFailureRule: events.Rule;
    /**
     * @stability stable
     */
    readonly allExecutionAttemptsFailedEventSource = "custom.aws.glue.allExecutionAttemptsFailed";
    /**
     * @stability stable
     */
    readonly allExecutionAttemptsFailedEventDetailType = "All Execution Attempts Failed";
    /**
     * @stability stable
     */
    readonly executionFailureRule: events.Rule;
    /**
     * @stability stable
     */
    readonly lambdaFunction: lambda.SingletonFunction;
    private allExecutionAttemptsFailedRule;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: GlueJobProperties);
    private createGlueJobRole;
    private jobRule;
    /**
     * @stability stable
     */
    metricSuccess(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @stability stable
     */
    metricFailure(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @stability stable
     */
    metricAllExecutionAttemptsFailed(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @stability stable
     */
    metricTimeout(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    private ruleMetric;
    /**
     * @stability stable
     */
    metric(metricName: string, dimensionType: string, props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @stability stable
     */
    jvmHeapUsageMetric(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @stability stable
     */
    elapsedTimeMetric(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @stability stable
     */
    diskSpaceUsedMbMetric(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * @stability stable
     */
    runTimeInMiliseconds(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    private createLambdaFunction;
}
